--メッセージ表示共通(Eventで実行しないように注意)
function GetEventMessage(...)
	local args = {...}
	for i=1,#args do
		if type(args[i]) == "table" then
			args[i] = args[i][LANGUAGE]
			break
		end
	end
	return args
end



--
-- Actor
--

Actor = {}
Actor.new = function(name,fname,depth)

	local this = {}
	local eventName = coroutine.name
	local instance = this;

	this.name = name;
	this.isAutoreleased = false

	--C#側のコマンド実行、インスタンスは、nameをキーに、dictionaryで管理
	if name ~= "" then
		AddActor(name,fname,depth)
		if string.find(eventName, "TitleEvent.TitleEvent_INIT") ~= nil then
			if EventSequence_AddActors[name] == nil then
				EventSequence_AddActors[name] = name;
			end
			--table.insert(EventSequence_AddActors,name)
		end
	end

	--画像の差し替え
	this.SetItemImage = function(icon)
		if name ~= "" then
			SetItemImage(name,icon)
		end
	end

	--アイテムアイコン設定
	this.SetItemIcon = function(itemId)
		if name ~= "" then
			local _icon = ExcuteGetItemIconName( itemId )
			SetItemImage(name,_icon)
		end
	end

	--配置設定
	this.SetPosition = function(x,y)
		if name ~= "" then
			SetPosition(name,x,y)
		end
	end

	--拡大縮小設定
	this.SetScale = function(x,y)
		if name ~= "" then
			SetScale(name,x,y)
		end
	end

	--回転設定
	this.SetRotation = function(z)
		if name ~= "" then
			SetRotation(name,z)
		end
	end

	--アクティブ
	this.SetActorActive = function(active)
		if name ~= "" then
			SetActorActive(name,active)
		end
	end

	this.GetPositionX = function()
		if name ~= "" then
			return tonumber(GetPositionX(name))
		end
		return 0
	end

	this.GetPositionY = function()
		if name ~= "" then
			return tonumber(GetPositionY(name))
		end
		return "0"
	end

	this.AutoRelease = function()
		if name ~= "" then
			AutoRelease(name)
			instance.isAutoreleased = true
		end
	end

	this.MoveTo = function(x,y,animId,speed,complete)
		if name ~= "" then
			MoveTo(name,eventName,x,y,animId,speed,complete)
		end
	end

	this.ScaleTo = function(x,y,animId,speed,complete)
		if name ~= "" then
			ScaleTo(name,eventName,x,y,animId,speed,complete)
		end
	end

	this.RotateTo = function(z,speed,loop)
		if name ~= "" then
			RotateTo(name,eventName,z,speed,loop)
		end
	end

	this.JumpTo = function(x,y,h,animId,speed,complete)
		if name ~= "" then
			JumpTo(name,eventName,x,y,h,animId,speed,complete)
		end
	end


	this.FadeIn = function(speed,complete)
		if name ~= "" then
			FadeIn(name,eventName,speed,complete)
		end
	end

	this.FadeOut = function(speed,complete)
		if name ~= "" then
			FadeOut(name,eventName,speed,complete)
		end
	end

	this.PlayAnimation = function(animId,loop)
		if name ~= "" then
			PlayAnimation(name,animId,loop)
		end
	end

	this.SetAnimationSpeed = function(speed)
		if name ~= "" then
			SetAnimationSpeed(name,speed)
		end
	end

	this.PauseAnimation = function()
		if name ~= "" then
			PauseAnimation(name)
		end
	end

	this.ResumeAnimation = function()
		if name ~= "" then
			ResumeAnimation(name)
		end
	end

	this.SetDepth = function(depth)
		if name ~= "" then
			SetDepth(name,depth)
		end
	end

	this.WaitAnimation = function()
		if name ~= "" then
			coroutine.yield("wait")
		end
	end

	this.DestroyActor = function()
		if name ~= "" then
			DestroyActor(name)
			name = ""
		end
	end

	return this
end


--
-- EventSelectMessage
--

EventSelectMessage = {}
EventSelectMessage.new = function(eventName,isMultiple,...)
	local this = {}
	local args = {...}

	local posY1 = 0
	local posY2 = 0
	local selectSound = "true"
	for i=1, #args do
		if args[i] == "positionY1" then
			posY1 = args[i+1]
		end
		if args[i] == "positionY2" then
			posY2 = args[i+1]
		end
		if args[i] == "selectSound" then
			selectSound = args[i+1]
		end
	end

	for i=1, #args do
		if args[i] == "positionY1" then
			table.remove(args, i)
			table.remove(args, i)
		end
	end

	for i=1, #args do
		if args[i] == "positionY2" then
			table.remove(args, i)
			table.remove(args, i)
		end
	end

	for i=1, #args do
		if args[i] == "selectSound" then
			table.remove(args, i)
			table.remove(args, i)
		end
	end

	if isMultiple == true then
		ExcuteEventMultiSelectMessage(eventName,args,posY1,posY2,selectSound)
	else
		ExcuteEventSelectMessage(eventName,args,selectSound)
	end

	return this
end


--
-- EventSequenceUtil
--

EventSequenceUtil = {}
EventSequenceUtil.new = function()
	local this = {}
	local eventName = coroutine.name

	--メッセージの表示 \nで改行 \pで改ページ
	this.ShowEventMessage = function(...)
		local args = GetEventMessage(...)
		--PrintLog("ShowEventMessage:"..eventName);
		ExcuteShowMessage(eventName,args)

		return EventSequence_EvtMsgComplete
	end

	--メッセージの表示 \nで改行 \pで改ページ
	this.ShowEventMessageWithActor = function(actor,animId,speed,...)
		if EventSequence_MsgComplete ~= nil then
			EventSequence_MsgComplete = nil
		end

		local args = GetEventMessage(...)
		actor.PlayAnimation(animId,"true")
		actor.SetAnimationSpeed(speed)
		ExcuteShowMessageWithActor(eventName,args)

		EventSequence_MsgComplete = this

		return EventSequence_MsgComplete
	end

	--メッセージ連動アニメの付け足し
	this.AddEventMessageEffectWithActor = function(actor,animId,speed)
		if EventSequence_MsgComplete ~= nil then
			EventSequence_MsgComplete = nil
		end

		actor.PlayAnimation(animId,"true")
		actor.SetAnimationSpeed(speed)

		EventSequence_MsgComplete = this

		return EventSequence_MsgComplete
	end

	--SE再生
	this.EventPlaySE = function(name,loop,complete)
		if EventSequence_SeComplete ~= nil then
			EventSequence_SeComplete = nil
		end

		ExcuteEventPlaySE(name,eventName,loop,complete)

		EventSequence_SeComplete = this

		return EventSequence_SeComplete
	end

	--SE再生（※クリーナー登録）
	this.EventPlaySEWithCleaner = function(name,loop,complete)
		ExecuteEventPushSEToCleaner( name )
		return this.EventPlaySE( name, loop, complete )
	end


	--メッセージ選択肢の表示
	this.SelectMessage = function(...)
		if EventSequence_SelectMessage ~= nil then
			EventSequence_SelectMessage = nil
		end

		EventSequence_SelectMessage = EventSelectMessage.new(eventName,false,...)

		return EventSequence_SelectMessage;
	end

	--メッセージ複数選択肢の表示
	this.MultiSelectMessage = function(...)
		if EventSequence_SelectMessage ~= nil then
			EventSequence_SelectMessage = nil
		end

		EventSequence_SelectMessage = EventSelectMessage.new(eventName,true,...)

		return EventSequence_SelectMessage;
	end

	--現在実行されているイベントの停止
	this.StopEvent = function()
		ExcuteStopEvent(eventName)
	end

	--強化の結果画面表示
	this.ShowEnhanceResult = function()
		ExcuteEnhanceEvent(eventName)
	end

	--進化の結果画面表示
	this.ShowEvolutionResult = function()
		ExcuteEvolutionEvent(eventName)
	end

	--指定座標タッチで、イベントを再生できるように
	this.SetTouchPosition = function(x1,y1,x2,y2)
		if EventSequence_TouchEvent ~= nil then
			EventSequence_TouchEvent = nil
		end

		ExcuteTouchEvent(x1,y1,x2,y2)

		EventSequence_TouchEvent = this

		return EventSequence_TouchEvent
	end

	return this
end


-- ==============================
-- フラグ操作関連
-- ==============================
-- リセット
function FlagReset()
	ExecuteFlagReset()
end

-- ブール設定
function FlagSetB( strId, boolVal )
	-- [nil]は[nil]として渡す（※削除）
	if boolVal == nil then
		ExecuteFlagSet( strId, nil )
	else
		ExecuteFlagSet( strId, tostring(boolVal) )
	end
end

-- ブール取得
function FlagGetB( strId )
	local val = ExecuteFlagGet( strId )	-- [val]は文字列

	-- [nil]は[false]として返す
	if val == nil then
		return false
	end

	if string.lower( val ) == "true" then
		return true
	end

	return false
end

-- 数値設定
function FlagSetN( strId, numVal )
	-- [nil]は[nil]として渡す（※削除）
	if numVal == nil then
		ExecuteFlagSet( strId, nil )
	else
		ExecuteFlagSet( strId, tostring(numVal) )
	end
end

-- 数値取得
function FlagGetN( strId )
	local val = ExecuteFlagGet( strId )	-- [val]は文字列

	-- [nil]は[0]として返す
	if val == nil then
		return 0
	end

	return tonumber(val)
end

-- 文字列設定
function FlagSetS( strId, strVal )
	-- [nil]は[nil]として渡す（※削除）
	if strVal == nil then
		ExecuteFlagSet( strId, nil )
	else
		ExecuteFlagSet( strId, tostring(strVal) )
	end
end

-- 文字列取得
function FlagGetS( strId )
	local val = ExecuteFlagGet( strId )	-- [val]は文字列

	-- [nil]は[""]として返す
	if val == nil then
		return ""
	end

	return val
end

-- 山手ダンジョンがリリースされているか？
function IsYamanoteDungeonReleased( strId )
	local result = ExecuteCheckYamanoteDungeonReleased( strId )
	return result
end

-- ゲストイベントがリリースされているか？
function IsGuestEventReleased( strId )
	local result = ExecuteCheckGuestEventReleased( strId )
	return result
end

-- 季節イベントがリリースされているか？
function IsSeasonEventReleased( strId )
	local result = ExecuteCheckSeasonEventReleased( strId )
	return result
end
--
-- Global Variables
--

EventSequenceMode = ""

EventSequenceParams = {
	level = 0, --開発レベル
	exp = 0, --獲得経験値
	yamadafunctions = {}, --解放した機能のリスト
	from = "", --HOMEの遷移で、どこから遷移してきたかの分岐
	isSkipBigRewardExp = 0, --ビッグリワードの経験値付与を、するか？ 0:する 1:しない
	isProduction = false, --製品版か？
	isBitsummit = false,
	isDebugBuild = false,
}

--C#側のみ、参照
EventDungeonPlayerMoveParams = {
	x = 0, --ダンジョンマップのX座標指定
	y = 0, --ダンジョンマップのY座標指定
	eventID = "", --EventIDの指定
	specialMonsterID = "", --特定のモンスターIDの指定
}
EventDungeonBossParams = {
	eventID = "" --EventIDの指定
}
EventSequence_SelectMessage = nil --メッセージ選択肢のインスタンスを保持するグローバル変数(C#側のみで使用)
EventSequence_TouchEvent = nil
EventSequence_MsgComplete = nil
EventSequence_MsgEndVoice = {}
EventSequence_MsgEndVoice.voice = {}
EventSequence_MsgEndVoice.voiceException = {}
EventSequence_MsgEndVoice.isVoiceException = false
EventSequence_MsgEndVoice.targetActorName = {}	-- Ver1.3.X:英語版対応 日本語環境以外の語尾ボイス再生処理を判定する為、アクターに関連する語尾テキストを設定するパラメーターを追加
EventSequence_EvtMsgComplete = {}
EventSequence_AutoMsgComplete = {}
EventSequence_SeComplete = nil;
EventSequence_YamadaMenuEvent = {}
EventSequence_SuspendResumeEvent = nil
EventSequence_IsMenuOpen = false
EventSequence_AnnouncementEvent = {}
EventSequence_AddActors = {}
EventSequence_EquipmentSetEvent = {}
EventSequence_LockDungeonSetEvent = {}
EventSequence_LockDungeonFormEvent = {}
EventSequence_Playable = "true"
EventSequence_DangerSkip = ""

-- タッチオブジェクト
EventSequence_TouchEventObj = {};
EventSequence_CurrentTouchTarget = nil;

-- 初期値
if FlagGetN("event_chapter") == nil then
	FlagSetN("event_chapter", -1);
end


--
-- Primitive functions
--

--イベントの呼び出し
function DispatchEvent(name)
	name = ExcuteCheckAdditionalLuaEvent(name)
	local f = loadstring("return "..name)
	local event = f()

	if event == nil then
		return
	end

	for key,v in pairs(event) do
		if key == "OnTouch" then
			--OnTouchが設定されていれば、以下を実行
			--loadstring("return "..name..".OnTouch(...)")("test")
			ExcuteOnTouch(name..".OnTouch")
			break
		end
	end

	ExecuteEventLua(name..".OnEnter")
end

--サスペンドレジュームでの、イベント呼び出し設定
function SetSuspendResumeEvent(name)
	if FlagGetB("bitsummit_play") == true then
		return
	end
	
	EventSequence_SuspendResumeEvent = name
end

--サスペンドレジュームでの、イベント呼び出し削除
function RemoveSuspendResumeEvent()
	EventSequence_SuspendResumeEvent = nil
end

--サスペンドレジュームで呼び出されるイベントが存在するか？
function HasSuspendResumeEvent()
	if FlagGetB("bitsummit_play") == true then
		return "false"
	end

	if EventSequence_SuspendResumeEvent ~= nil then
		return "true"
	end
	return "false"
end

--サスペンドレジュームで設定したイベントがあれば呼び出す。
function DispatchSuspendResumeEvent()
	if FlagGetB("bitsummit_play") == true then
		return
	end

	if EventSequence_SuspendResumeEvent ~= nil then
		DispatchEvent(EventSequence_SuspendResumeEvent)
	end
end

--イベントデモが再生中か？
function IsEventDemoPlaying()
	if FlagGetB("event_demo_playing") ~= nil then
		if FlagGetB("event_demo_playing") == true then
			return "true"
		end
		return "false"
	end
	return "false"
end

--オブジェクトの生成
function CreateActor(name,fname,depth)
	if depth == nil then
		depth = 0;
	end

	return Actor.new(name,fname,depth)
end

--生成したオブジェクトの破棄
function DestroyInitialActor(target)
	if target ~= nil then
		if target.isAutoreleased == false then
			DestroyActor(target)
		end
	end
end

function CreateEventUtil()
	return EventSequenceUtil.new()
end

--アニメーション終了まで待つ
function WaitEventAnimation()
	coroutine.yield("wait")
end

--次の処理を待つ
function WaitForSeconds(time)
	coroutine.yield(time)
end

--メッセージの表示 \nで改行 \pで改ページ
function ShowEventMessage(...)
	local args = GetEventMessage(...)
	--PrintLog("ShowEventMessage:"..coroutine.name);
	ExcuteShowMessage(coroutine.name,args)
end

--メッセージを読み終わるまで、以下、処理させない
function WaitEventMessage()
	coroutine.yield("wait")
end

--選択肢が閉じるまで、以下、処理させない
function WaitEventSelectMessage()
	coroutine.yield("wait")
end

--メッセージが表示され、指定秒数で自動で閉じる
function AutoEventMessage(...)
	local args = GetEventMessage(...)
	ExcuteShowAutoMessage(args)

	return EventSequence_AutoMsgComplete;
end

--メッセージのスピード設定
function SetEventMessageSpeed(speed)
	ExcuteSetMessageSpeed(speed)
end

--プレイアブル/アンプレイアブル
function EventPlayable(flg)
	-- 思い出再生中は無視
	if ExecuteIsMemoryPlaying() then
		return
	end

	ExcuteEventPlayable(flg)
	EventSequence_Playable = flg
end

--画面全体のフェードイン
function EventFadeIn(speed, depth, renderQ)
	ExcuteEventFadeIn(speed, depth, renderQ)
end

--画面全体のフェードアウト
function EventFadeOut(speed, depth, renderQ)
	ExcuteEventFadeOut(speed, depth, renderQ)
end

--画面全体のホワイトイン
function EventFadeWhiteIn(speed, depth, renderQ)
	ExcuteEventFadeWhiteIn(speed, depth, renderQ)
end

--画面全体のホワイトアウト
function EventFadeWhiteOut(speed, depth, renderQ)
	ExcuteEventFadeWhiteOut(speed, depth, renderQ)
end

--画面全体のマスクフェードイン
function EventMaskFadeIn(maskname, x, y, speed, depth, renderQ)
	ExcuteEventMaskFadeIn(maskname, x, y, speed, depth, renderQ)
end

--画面全体のマスクフェードアウト
function EventMaskFadeOut(maskname, x, y, speed, depth, renderQ)
	ExcuteEventMaskFadeOut(maskname, x, y, speed, depth, renderQ)
end

--部屋の位置設定
function EventSetRoomPosition(x, y)
	ExcuteSetRoomPosition(x, y)
end

--部屋の位置移動
function EventRoomMoveTo(x, y, speed)
	ExcuteRoomMoveTo(x, y, speed)
end

--部屋のズーム
function EventRoomZoom(x, y, scale, speed)
	ExcuteEventRoomZoom(x, y, scale, speed)
end

--BGM再生(ループあり)
function EventPlayBGM(name)
	ExcuteEventPlayBGM(name)
end

--BGM停止
function EventStopBGM(name)
	ExcuteEventStopBGM(name)
end

--BGM(ループ無し)
function EventPlayBGMAtOnce(name)
	ExcuteEventPlayBGMAtOnce(name)
end

--SEの停止
function EventStopSE(name)
	ExcuteEventStopSE(name)
end

--全てのSEの停止
function EventStopAllSE()
	ExcuteEventStopAllSE()
end

--指定されたSE以外を、全て停止
function EventStopAllExceptSelectedSE(table)
	ExcuteEventStopAllExceptSelectedSE(table)
end

--クリーナーに登録された全てのSEの停止
function EventStopAllSEWithCleaner()
	ExecuteEventStopAllSEWithCleaner()
end

--SEのフェードイン
function EventFadeInSE(time,name)
	ExcuteEventFadeInSE(time,name)
end

--SEのフェードアウト
function EventFadeOutSE(time,name)
	ExcuteEventFadeOutSE(time,name)
end

--全てのSEのフェードアウト
function EventFadeOutAllSE(time)
	ExcuteEventFadeOutAllSE(time)
end

--指定されたSE以外を、全てフェードアウト
function EventFadeAllExceptSelectedSE(time,table)
	ExcuteEventFadeAllExceptSelectedSE(time,table)
end

--クリーナーに登録されたSEを、全てフェードアウト
function EventFadeOutAllSEWithCleaner(time)
	ExecuteEventFadeOutAllSEWithCleaner(time)
end

--BGMのフェードイン
function EventFadeInBGM()
	ExcuteEventFadeInBGM()
end

--BGMのフェードアウト
function EventFadeOutBGM()
	ExcuteEventFadeOutBGM()
end

--SE再生終了を待つ
function WaitEventSE()
	coroutine.yield("wait")
end

--イベント中の中間にイベントフラグのsave
function SaveEventFlagMiddle()
	ExcuteSaveEventFlagMiddle()
end

--イベント中の最後にイベントフラグのsave
function SaveEventFlagEnd()
	ExcuteSaveEventFlagEnd()
end

--セーブデータの削除
function DeleteSaveData()
	--上記処理は下記[CS]処理で置き換わる
	ExecuteBridgeDeleteSaveData()

	FlagReset()
	if FlagGetN("event_chapter") == nil then
		FlagSetN("event_chapter", -1)
	end

	ExcuteSaveEventFlagMiddle()
end

--特定マスに行くとイベントが発生するようにする設定
function SetPlayerMoveEventTrigger(x,y,id,...)
	local args = {...}
	EventDungeonPlayerMoveParams.x = x
	EventDungeonPlayerMoveParams.y = y
	EventDungeonPlayerMoveParams.eventID = id
	if args[1] ~= nil then
		EventDungeonPlayerMoveParams.specialMonsterID = args[1]
	end
end

--特定のボスで負けるとイベント発生
function SetDungeonBossLoseEvent(id)
	EventDungeonBossParams.eventID = id
	--ExecuteBridgeSetStringByName( "PlayerParams.incompleteLoseBossEvent", id )
end

--強化成功の終了を待つ
function WaitEnhanceResultMessage()
	coroutine.yield("wait")
end

--進化成功の終了を待つ
function WaitEvolutionResultMessage()
	coroutine.yield("wait")
end

--各配置物に対してのタッチ処理
function SetTouchEvent(name,x1,y1,x2,y2)
	EventSequence_TouchEventObj[name] = {
		x1 = x1,
		x2 = x2,
		y1 = y1,
		y2 = y2
	}
	PrintLog("=========== SetTouchEvent:"..name)
	return EventSequence_TouchEventObj[name]
end

--C#側から、タッチした際にコールされる
function UpdateTouch(x,y)
	PrintLog("1=========== UpdateTouch:")
	local tx = tonumber(x)
	local ty = tonumber(y)
	for k,v in pairs(EventSequence_TouchEventObj) do
		if EventSequence_TouchEventObj[k] ~= nil then
			if (tx>=EventSequence_TouchEventObj[k].x1 and ty<=EventSequence_TouchEventObj[k].y1 and tx<=EventSequence_TouchEventObj[k].x2 and ty>=EventSequence_TouchEventObj[k].y2) then
				--ExcuteHideMainMenu();
				PrintLog("2=========== UpdateTouch:"..k)
				EventSequence_TouchEventObj[k].OnTouched()
				EventSequence_CurrentTouchTarget = k;
			end
		end
	end
end

--C#側から、タッチアップした際に、呼び出される。
function UpdateTouchEnd()
	PrintLog("1=========== UpdateTouchEnd:")
	local key = EventSequence_CurrentTouchTarget
	if key ~= nil then
		if EventSequence_TouchEventObj[key] ~= nil then
			if EventSequence_TouchEventObj[key].OnTouchEnded ~= nil then
				PrintLog("2=========== UpdateTouchEnd:"..k)
				EventSequence_TouchEventObj[key].OnTouchEnded()
				EventSequence_CurrentTouchTarget = ""
			end
		end
	end
end

--イベントで、設定した、タッチ座標か？
function HasTouchEvent(x,y)
	local tx = tonumber(x)
	local ty = tonumber(y)
	for k,v in pairs(EventSequence_TouchEventObj) do
		if EventSequence_TouchEventObj[k] ~= nil then
			if (tx>=EventSequence_TouchEventObj[k].x1 and ty<=EventSequence_TouchEventObj[k].y1 and tx<=EventSequence_TouchEventObj[k].x2 and ty>=EventSequence_TouchEventObj[k].y2) then
				return "true"
			end
		end
	end
	return "false"
end

--タッチ処理無効可
function DeleteTouchEvent(name)
	PrintLog("=========== DeleteTouchEvent:"..name)
	EventSequence_TouchEventObj[name] = nil

	for k,v in pairs(EventSequence_TouchEventObj) do
		PrintLog("2 =======DeleteTouchEvents:"..k)
	end
end

--タッチイベントを全て削除
function DeleteAllTouchEvents()
	EventSequence_TouchEventObj = nil
	EventSequence_TouchEventObj = {}
end

--Lua側、現在設定されている、タッチイベントの名前を
function GetCurrentTouchEventNames()
	local str = ""
	for k,v in pairs(EventSequence_TouchEventObj) do
		PrintLog("=======GetCurrentTouchEventNames"..k)
		if EventSequence_TouchEventObj[k] ~= nil then
			str = str..k.."\n"
		end
	end
	return str
end

--指定座標タッチ処理の無効可
function RemoveTouchEvent()
	EventSequence_TouchEvent = nil
	EventSequence_TouchEventObj = nil
	EventSequence_TouchEventObj = {}
	ExcuteResetTouchPosition()
end

--あといくつのEXPで、レベルアップか？
function GetExpNeedsNextLevel()
	local maxExp = tonumber(ExecuteBridgeGetStringByName( "PlayerParams.maxExp" ))
	local exp = tonumber(ExecuteBridgeGetStringByName( "PlayerParams.exp" ))
	return maxExp - exp
end

--ビッグリワードの経験値設定変更できるように
function SkipAddBigRewardExp()
	EventSequenceParams.isSkipBigRewardExp = 1
end

--パコの時間を取得
function GetPakoTime()
	return tonumber(ExcuteGetPakoTime())
end

--集めたモンスターの数を取得
function GetMonsterCollectionNum()
	return tonumber(ExcuteGetMonsterCollectionNum())
end

--指定したモンスターを倒してるか？
function hasBeatedMonster(id)
	if ExcuteIsBeatedMonster(id) == "true" then
		return true
	end
	return false
end

--ダンジョンごとに設定されたボスが存在するか？のフラグ設定 true:存在する
function SetDungeonBossExists(dungeonID,flg)
	local val = 0

	if type(flg) == "boolean" then
		if flg == true then
			val = 1
		end
	elseif type(flg) == "string" then
		if flg == "true" then
			val = 1
		end
	end

	ExecuteBridgeSetDungeonBossExists( dungeonID, val )
end

--掃除機能が使えるか？
function IsCleanupAvailable()
	if ExcuteIsCleanupAvailable() == "true" then
		return true;
	end
	return false;
end

--掃除機能の解放
function UnlockCleanup()
	ExcuteUnlockCleanup()
end

--ゴミ散らかし時間をセット
function SetCleanupTimeLeft(sec)
	ExcuteSetCleanupTimeLeft(sec)
end

--ゴミ散らかしの経過時間を取得
function GetCleanupTimeLeft()
	return tonumber(ExcuteGetCleanupTimeLeft())
end

--ゴミ散らかしの経過時間をリセット
function ResetCleanupTimeLeft()
	ExcuteResetCleanupTimeLeft()
end

--所持数最大値を設定
function SetItemMax(num)
	ExcuteExpandSokoForDebug( num )
	--ExecuteBridgeSetIntByName( "PlayerParams.maxItems", num )
end

--画面左端のx座標をgetする。
function GetPositionScreenLeftX()
	return tonumber(ExcuteGetPositionScreenLeftX())
end

--画面右端のx座標をgetする。
function GetPositionScreenRightX()
	return tonumber(ExcuteGetPositionScreenRightX())
end

--画面上端のy座標をgetする。
function GetPositionScreenTopY()
	return tonumber(ExcuteGetPositionScreenTopY())
end

--画面下端のy座標をgetする。
function GetPositionScreenBottomY()
	return tonumber(ExcuteGetPositionScreenBottomY())
end

--ヤマダ部屋のデバッグメニューや、各コンテンツが表示されているか？
function IsMenuOpen()
	return EventSequence_IsMenuOpen
end

--EventSequence_IsMenuOpenがtrueだった場合、イベント側で、falseに更新
function UpdateMenuOpenFlag(flg)
	EventSequence_IsMenuOpen = flg
end

--イベント告知の表示
function ShowEventAnnouncement()
	ExcuteShowAnnouncementRequest();
	return EventSequence_AnnouncementEvent;
end

--限定ダンジョンの巻物がいっぱいか？
function isLockDungeonFull()
	if GetCurrentLockDungeonListCount ~= nil then
		local max = tonumber(GetLockDungeonListMax())+1
		local num = GetCurrentLockDungeonListCount()
		if num >= max then
			return true
		end
	end
	return false
end

--山手線ダンジョンか？
function isYamanoteDungeon()
	local res = ExcuteIsYamanoteDungeon()
	if res == "true" then
		return true
	end
	return false
end

function CallMsgEndVoice(voice)
	if EventSequence_MsgEndVoice ~= nil then 
		if EventSequence_MsgEndVoice.OnStart ~= nil then 
			EventSequence_MsgEndVoice.OnStart(voice) 
		end 
	end
end

--デバッグモード設定
function SetDebugMode()
	EventSequenceMode = "debug"
end

--リリース用ビルド設定
function SetProductionBuild(flg)
	if flg == "true" then
		EventSequenceParams.isProduction = true
	end
end

function IsProduction()
	return EventSequenceParams.isProduction
end

--BItsummit用ビルド設定
function SetBitsummitBuild(flg)
	if flg == "true" then
		EventSequenceParams.isBitsummit = true
	end
end

function IsBitsummit()
	return EventSequenceParams.isBitsummit
end

--デバッグ用ビルド設定（※デバッグ用のLuaスクリプトが有効であるか？）
function SetDebugBuild(flg)
	if flg == "true" then
		EventSequenceParams.isDebugBuild = true
	end
end

function IsDebugBuild()
	return EventSequenceParams.isDebugBuild
end

function IsFunctionalRestrictionBuild()
	-- [0.9.0]申請版では機能制限
	--return true
	return false
end
--
